/////////////////////////////////////////////////////////////////////
// Address Decoder for DC-5 Floppy Disk Controller
// Michael Holley - Nov. 14, 2001
/////////////////////////////////////////////////////////////////////
// 16 Bit I/O slots (E0xx on 6809)
// Port 1 is E010 to E01F, this card uses E014 to E01B
//
// 4 Bit I/O slots (80xx on 6800, E0xx on 6809)
// Port 6 is E018 to E01B - WD2797
// Port 5 is E014 to E017 - Status and Control Register
// I/O Select for port 5 is wired to UD3 (RS2)
//
module AddrDecode(RS3,RS2,RS1,RS0,IO_Select,Mode_416,Mode_2Reg,Mode_Cal,
                  FDC_Select, CTRL_Select, Reg1_Select,
                  Reg2_Select, Timer_Select, A1,A0);

    input  RS3, RS2, RS1, RS0;
    input  IO_Select;
    input  Mode_416, Mode_2Reg, Mode_Cal;
    output FDC_Select, CTRL_Select; 
    output Reg1_Select, Reg2_Select, Timer_Select;
    output A1, A0;

    wire E018_B, E014_7;
    wire E014, E015, E016, E017;

    assign E018_B =  Mode_416 & ~IO_Select &  RS3 & ~RS2
                  | ~Mode_416 & ~IO_Select;

    assign E014_7 =  Mode_416 & ~IO_Select & ~RS3 &  RS2 
                  | ~Mode_416 & ~RS2;

    assign E014   =  Mode_416 & ~IO_Select & ~RS3 &  RS2 & ~RS1 & ~RS0
                  | ~Mode_416 & ~RS2                     & ~RS1 & ~RS0;

    assign E015   =  Mode_416 & ~IO_Select & ~RS3 &  RS2 & ~RS1 &  RS0
                  | ~Mode_416 & ~RS2                     & ~RS1 &  RS0;

    assign E016   =  Mode_416 & ~IO_Select & ~RS3 &  RS2 &  RS1 & ~RS0
                  | ~Mode_416 & ~RS2                     &  RS1 & ~RS0;

    assign E017   =  Mode_416 & ~IO_Select & ~RS3 &  RS2 &  RS1 &  RS0
                  | ~Mode_416 & ~RS2                     &  RS1 &  RS0;

    // Outputs
    assign CTRL_Select    = E014_7 | Timer_Select;

    assign FDC_Select     = E018_B & (Mode_Cal == 1'b1);

    assign Timer_Select   = E018_B & (Mode_Cal == 1'b0);

    assign Reg1_Select    = (Mode_2Reg == 1'b1) & E014_7 | 
                            (Mode_2Reg == 1'b0) & (E014 | E015);

    assign Reg2_Select    = (Mode_2Reg == 1'b0) & (E016| E017);

    assign A1 = RS1;

    assign A0 = RS0;

endmodule
