/////////////////////////////////////////////////////////////////////
// FDC Clock Circuit for DC-5 Floppy Disk Controller
// Michael Holley - Nov. 14, 2001
/////////////////////////////////////////////////////////////////////
// The FDC clock is derived from a 12 MHz external oscillator.
// The standard 5.25 inch floppy requires 1.0 MHz, the 3.5 inch floppy 
// drive requires 1.2 MHz and the 8 inch floppy drive requires 2.0 Mhz.
//
// Osc12 = 0 and Osc20 = 0 Divide by 12  1.0 Mhz
// Osc12 = 1 and Osc20 = 0 Divide by 10  1.2 MHz
// Osc12 = 0 and Osc20 = 1 Divide by  6  2.0 MHz
// Osc12 = 1 and Osc20 = 1 Don't Care
//
// Osc20 is bit 3 (^h08) of Reg2 and Osc12 is bit 2 (^h04).
//
// This is implemented by a programmable divider (3,5 or 6)
// followed by a divide by 2 to give a 50% duty cycle.
//
module ClockGen(Osc12,Osc20,Osc,Reset,FDC_Clk);
    input  Osc12, Osc20, Osc, Reset;
    output FDC_Clk;

    reg [2:0] Q; // programmable divider
    reg Q3;      // divide by 2

always@(posedge Osc or negedge Reset)
   begin
      if(~Reset)  
         begin
            Q  = 3'b000;
            Q3 = 1'b0;
         end
      else if(Osc20 && Q == 3'b010) // Divide by 3 (0 to 2)
         begin
	         Q  = 3'b000;
            Q3 = ~Q3;
         end
      else if(Osc12 && Q == 3'b100) // Divide by 5 (0 to 4)
         begin
	         Q  = 3'b000;
            Q3 = ~Q3;
         end
      else if(~Osc12 && Q == 3'b101) // Divide by 6 (0 to 5)
         begin
	         Q  = 3'b000;
            Q3 = ~Q3;
         end
      else
         Q = Q + 1;
   end

   assign FDC_Clk = Q3;

endmodule
