/////////////////////////////////////////////////////////////////////
// Control Register for DC-5 Floppy Disk Controller
// Michael Holley - Nov. 09, 2001
/////////////////////////////////////////////////////////////////////
//
// Traditional Control Register Bits
//           [   7       6      5        4     3    2     1   0 ]
//  Reg1   = [DS_INH,Side_Sel, .X.  ,   .X. , .X., .X.  ,DS1,DS0];
//
// New Control Register Bits
//           [   7       6      5        4     3    2     1   0 ]
//  Reg2   = [  .X. ,   .X.  ,DD_Ena,FiveOr8,Osc20,Osc12,.X.,.X.];

module ControlReg(Reg1_Select, Reg2_Select, RW, E, Data, Reset,
                  DS_INH, Side_Sel, DD_Ena, FiveOr8,
                  Osc20, Osc12, DS1, DS0);

   input  Reg1_Select, Reg2_Select;
   input  RW, E;
   input  [7:0] Data;
   input  Reset;
   output DS_INH, Side_Sel, DS1, DS0;
   output DD_Ena ,FiveOr8, Osc20,Osc12;

   wire Clk1, Clk2;
   reg DS_INH, Side_Sel, DS1, DS0;
   reg DD_Ena ,FiveOr8, Osc20,Osc12;

   // Control Register 1
   assign Clk1 =  Reg1_Select & ~RW & ~E;

   always @(posedge Clk1 or negedge Reset) begin
      if(Reset == 'b0)
         {DS_INH,Side_Sel,DS1,DS0} = 4'b0000;
      else
         {DS_INH,Side_Sel,DS1,DS0} = {Data[7],Data[6],Data[1],Data[0]};
   end

   // Control Register 2
   assign Clk2 =  Reg2_Select & ~RW & ~E;
   always @(posedge Clk2 or negedge Reset) begin
      if(Reset == 'b0)
         {DD_Ena,FiveOr8,Osc20,Osc12} = 4'b0000;
      else
         {DD_Ena,FiveOr8,Osc20,Osc12} = {Data[5],Data[4],Data[3],Data[2]};
   end

endmodule
