/////////////////////////////////////////////////////////////////////
// FDC interface for DC-5 Floppy Disk Controller
// Michael Holley - Dec. 01, 2001
/////////////////////////////////////////////////////////////////////
//            Floppy Disk Controller (FDC) interface 
// The FDC data and the INTRQ / DRQ status lines are multiplexed
// onto the SS30 data bus. During the read cycle when RW is high 
// and the address is between E014 and E01B the buffers to SS30 
// data bus are enabled. The FDC data is present except when the
// address is between E014 and E017.
//
// The SS30 data bus to routed to the FDC data pins. The buffers
// to the FDC are tri-state except when RW is low and 
// the address is between E018 and E01B. 
//
module DataMux(DataIn,CountIn,DRQ,INTRQ,
               FDC_Select, Reg1_Select, Reg2_Select, Timer_Select,
               IRQ,DataOut);
    input [7:0] DataIn;
    input [7:0] CountIn;
    input DRQ;
    input INTRQ;
    input FDC_Select, Timer_Select, Reg2_Select, Reg1_Select;

    output IRQ;
    reg IRQ;
    output [7:0] DataOut;
    reg [7:0] DataOut;

   always @(FDC_Select or Timer_Select or Reg2_Select or
            DataIn or CountIn or DRQ or INTRQ) // synthesis parallel_case
      begin
         if (FDC_Select)
            DataOut = DataIn;
        else if (Timer_Select)
            DataOut = CountIn; 
        else if (Reg2_Select)
            DataOut =  8'b00000010; // Version
        else // Reg1_Select
            DataOut = {DRQ,INTRQ, 6'b000000};
      end

   // Emulate open drain signal for SS-30 bus
   always @(DRQ) begin
      if (~DRQ)
         IRQ = 1'b0;
      else
         IRQ = 1'bz;
   end

endmodule
