/////////////////////////////////////////////////////////////////////
// Disk Drive Select for DC-5 Floppy Disk Controller
// Michael Holley - Nov. 14, 2001
/////////////////////////////////////////////////////////////////////
//
// New 3.5 inch drives are all hard wired to Drive 1
// and need an IBM PC twisted cable as follows:
// Pin 10 Motor Enable A 
// Pin 12 Drive Select B 
// Pin 14 Drive Select A
// Pin 16 Motor Enable B
// Drive A is after twist at the end of the cable.
   
// SWTPC and standard drives are as follows:
// Pin 10 Drive Select 0 
// Pin 12 Drive Select 1
// Pin 14 Drive Select 2
// Pin 16 Motor Enable all drives
   
module DriveSelect(DS1, DS0, DS_INH, Motor, Mode_35Disk,
                   Drive3, Drive2, Drive1, Drive0, Motor_On);
    input DS1, DS0;
    input DS_INH, Motor, Mode_35Disk;
   output Drive3, Drive2, Drive1, Drive0;
   output Motor_On;
   reg Drive2, Drive0;

   always @(Mode_35Disk or Motor or DS1 or DS0 or DS_INH) // synthesis parallel_case
   begin
      if (Mode_35Disk == 1'b0) // Switch 3 ON - Logic Low
         begin
            Drive0 =  Motor;                        // Motor
            Drive2 = ~DS1 & ~DS0 & ~DS_INH & Motor; // Drive 0 
         end
      else
         begin
            Drive0 = ~DS1 & ~DS0 & ~DS_INH & Motor; // Drive 0
            Drive2 =  DS1 & ~DS0 & ~DS_INH & Motor; // Drive 2
         end
   end

   assign Drive1 = ~DS1 &  DS0 & ~DS_INH & Motor;  // Drive 1

   assign Drive3 =  DS1 &  DS0 & ~DS_INH & Motor;  // Drive 3

   assign Motor_On = Motor;

endmodule
