/////////////////////////////////////////////////////////////////////
// Timer for DC-5 Floppy Disk Controller
// Michael Holley - Nov. 12, 2001
/////////////////////////////////////////////////////////////////////
module Timer(Osc,Timer_Select,RW,PulseIn,Reset,Count);
    input Osc, Timer_Select, RW, PulseIn, Reset;
    output [7:0] Count;
    reg [7:0] Count;

    reg Pulse;

    // State Register
    reg [2:0] current_state /* synthesis state_machine */;
    reg [2:0] next_state;
    // Define States
    parameter Wait_1   = 3'b000, 
              Wait_2   = 3'b001,
              Counting = 3'b010,
              Done     = 3'b100;

   always @(Pulse or Timer_Select or RW or current_state)
   begin
      case(current_state)
      Wait_1:
         if(~Pulse)     next_state = Wait_2;
      Wait_2:
         if(Pulse)      next_state = Counting;
      Counting:
         if(~Pulse)     next_state = Done;
      Done:
         if(Timer_Select & ~RW) next_state = Wait_1; 
      endcase
   end

   // State Machine Registers
   always @ (posedge Osc or negedge Reset)
      begin
         if (~Reset)
            begin
   	        current_state = Wait_1;
              Pulse = 0;
            end
         else
            begin
   	        current_state = next_state;
              Pulse = PulseIn; // Sync to common clock
            end
      end

   // Counter Registers
   always@(posedge Osc)
      begin
         if(current_state == Wait_2)  
            Count = 8'b0000000;
         else if(current_state == Counting)
            Count = Count + 1;
      end
endmodule
